# Generated by Django 5.0 on 2023-12-24 09:07

import django.db.models.deletion
import django_fsm
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="Election",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("slug", models.SlugField(max_length=40, unique=True)),
                ("name", models.CharField(max_length=100)),
                (
                    "state",
                    django_fsm.FSMField(
                        choices=[
                            ("pre_nominating", "Pre-Nomination"),
                            ("nominating_preview", "Nomination Preview"),
                            ("nominating", "Nominating"),
                            ("nominating_closed", "Nominating Closed"),
                            ("voting_preview", "Voting Preview"),
                            ("voting", "Voting"),
                            ("voting_closed", "Voting Closed"),
                        ],
                        default="pre_nominating",
                        max_length=50,
                    ),
                ),
            ],
            options={
                "permissions": [
                    ("nominate", "Can nominate in WSFS elections"),
                    ("preview_nominate", "Can nominate during the preview phase"),
                    ("vote", "Can vote in WSFS elections"),
                    (
                        "preview_vote",
                        "Can vote in WSFS elections during the preview phase",
                    ),
                ],
            },
        ),
        migrations.CreateModel(
            name="Category",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("name", models.CharField(max_length=100)),
                ("description", models.TextField()),
                ("details", models.TextField()),
                ("ballot_position", models.SmallIntegerField()),
                ("fields", models.SmallIntegerField(default=1)),
                ("field_1_description", models.CharField(max_length=100)),
                ("field_2_description", models.CharField(max_length=100, null=True)),
                ("field_3_description", models.CharField(max_length=100, null=True)),
                (
                    "election",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        to="nominate.election",
                    ),
                ),
            ],
            options={
                "verbose_name_plural": "categories",
            },
        ),
        migrations.CreateModel(
            name="Finalist",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("description", models.TextField()),
                (
                    "category",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="nominate.category",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="NominatingMemberProfile",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("preferred_name", models.CharField(max_length=100, null=True)),
                ("member_number", models.CharField(max_length=100, null=True)),
                (
                    "user",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="convention_profile",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
            options={
                "verbose_name": "Nominating Member Profile",
            },
        ),
        migrations.CreateModel(
            name="Nomination",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("field_1", models.CharField(max_length=200)),
                ("field_2", models.CharField(max_length=200)),
                ("field_3", models.CharField(max_length=200)),
                ("nomination_date", models.DateTimeField(auto_now=True)),
                ("nomination_ip_address", models.CharField(max_length=64)),
                (
                    "category",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        to="nominate.category",
                    ),
                ),
                (
                    "nominator",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        to="nominate.nominatingmemberprofile",
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="VotingMember",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "elections",
                    models.ManyToManyField(
                        to="nominate.election", verbose_name="Participating Votes"
                    ),
                ),
                (
                    "user",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="voter_profile",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
            ],
        ),
        migrations.CreateModel(
            name="Rank",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("position", models.PositiveSmallIntegerField()),
                (
                    "finalist",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="nominate.finalist",
                    ),
                ),
                (
                    "membership",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="nominate.votingmember",
                    ),
                ),
            ],
        ),
    ]
